from typing import Annotated
import logging

from fastapi import (
    FastAPI,
    Depends,
    HTTPException,
    status,
)
from fastapi.responses import FileResponse, HTMLResponse
from pydantic import BaseModel
from sqlalchemy.sql.base import ExecutableOption
from sqlalchemy.exc import NoResultFound
from sqlmodel import select
from sqlmodel.ext.asyncio.session import AsyncSession
from hatchet_sdk.runnables.types import EmptyModel

from knoc.settings import settings
from knoc.workflows import all_wfs
from knoc.workflows.utils import ImportReport
from knoc.db import engine, aio_sql_to_df, get_session

from knoc_plugin_template.workflows import SimpleOutput, do_nothing_wf

logger = logging.getLogger("knoc-plugin-template.api")


app = FastAPI()


@app.get("/")
async def template_api_home() -> HTMLResponse:
    return HTMLResponse("<p>Plugin template home</p>")


@app.get("/run_wf")
async def template_api_execute_wf() -> dict[str, SimpleOutput]:
    result = await do_nothing_wf.aio_run(EmptyModel())
    return result
